@@ -2,7 +2,7 @@
 /**
  * This file contains the Horde_Url class for manipulating URLs.
  *
- * Copyright 2009-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2009-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -384,7 +384,7 @@ class Horde_Url
      *
      * @return string  URL-safe, base64 encoded data.
      */
-    static public function uriB64Encode($string)
+    public static function uriB64Encode($string)
     {
         return str_replace(array('+', '/', '='), array('-', '_', ''), base64_encode($string));
     }
@@ -396,7 +396,7 @@ class Horde_Url
      *
      * @return string  Decoded data.
      */
-    static public function uriB64Decode($string)
+    public static function uriB64Decode($string)
     {
         $data = str_replace(array('-', '_'), array('+', '/'), $string);
         $mod4 = strlen($data) % 4;
