@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2013-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2013-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
  *
  * @category  Horde
- * @copyright 2013-2014 Horde LLC
+ * @copyright 2013-2015 Horde LLC
  * @license   http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package   Url
  */
@@ -16,7 +16,7 @@
  *
  * @author    Michael Slusarz <slusarz@horde.org>
  * @category  Horde
- * @copyright 2013-2014 Horde LLC
+ * @copyright 2013-2015 Horde LLC
  * @license   http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package   Url
  */
@@ -50,7 +50,7 @@ class Horde_Url_Data
      * @param string $data     The data.
      * @param boolean $base64  Should data be base64 encoded?
      */
-    static public function create($type = null, $data = null, $base64 = true)
+    public static function create($type = null, $data = null, $base64 = true)
     {
         $ob = new self();
 
@@ -76,7 +76,7 @@ class Horde_Url_Data
      *
      * @return boolean  True if the input contains RFC 2397 compliant data.
      */
-    static public function isData($input)
+    public static function isData($input)
     {
         if (is_object($input)) {
             return ($input instanceof self);
